@@ -54,7 +54,8 @@ int ffindex_insert_memory(FILE *data_file, FILE *index_file, size_t *offset, cha
 
     /* Seperate by '\0' and thus also make sure at least one byte is written */
     char buffer[1] = {'\0'};
-    fwrite(buffer, sizeof(char), 1, data_file);
+    if(fwrite(buffer, sizeof(char), 1, data_file) != 1)
+      perror("ffindex_insert_memory");
     *offset += 1;
     if(ferror(data_file) != 0)
       goto EXCEPTION_ffindex_insert_memory;
@@ -62,7 +63,6 @@ int ffindex_insert_memory(FILE *data_file, FILE *index_file, size_t *offset, cha
     /* write index entry */
     fprintf(index_file, "%s\t%zd\t%zd\n", name, offset_before, *offset - offset_before);
 
-
     return myerrno;
 
 EXCEPTION_ffindex_insert_memory:
@@ -156,10 +156,13 @@ int ffindex_insert_filestream(FILE *data_file, FILE *index_file, size_t *offset,
       if(read_size != write_size)
         fferror_print(__FILE__, __LINE__, __func__, name);
     }
+    if(ferror(file))
+      warn("fread");
 
     /* Seperate by '\0' and thus also make sure at least one byte is written */
     buffer[0] = '\0';
-    fwrite(buffer, sizeof(char), 1, data_file);
+    if(fwrite(buffer, sizeof(char), 1, data_file) != 1)
+      perror("ffindex_insert_filestream");
     *offset += 1;
     if(ferror(data_file) != 0)
       goto EXCEPTION_ffindex_insert_file;
@@ -208,6 +211,10 @@ static int ffindex_compare_entries_by_name(const void *pentry1, const void *pent
   return strncmp(entry1->name, entry2->name, FFINDEX_MAX_ENTRY_NAME_LENTH);
 }
 
+ffindex_entry_t* ffindex_get_entry_by_name(ffindex_index_t *index, char *name)
+{
+  return ffindex_bsearch_get_entry(index, name);
+}
 
 ffindex_entry_t* ffindex_bsearch_get_entry(ffindex_index_t *index, char *name)
 {
@@ -223,17 +230,18 @@ ffindex_index_t* ffindex_index_parse(FILE *index_file, size_t num_max_entries)
     num_max_entries = FFINDEX_MAX_INDEX_ENTRIES_DEFAULT;
   size_t nbytes = sizeof(ffindex_index_t) + (sizeof(ffindex_entry_t) * num_max_entries);
   ffindex_index_t *index = (ffindex_index_t *)malloc(nbytes);
-  index->num_max_entries = num_max_entries;
   if(index == NULL)
   {
+    fprintf(stderr, "Failed to allocate %ld bytes\n", nbytes);
     fferror_print(__FILE__, __LINE__, __func__, "malloc failed");
     return NULL;
   }
+  index->num_max_entries = num_max_entries;
 
   index->file = index_file;
   index->index_data = ffindex_mmap_data(index_file, &(index->index_data_size));
   if(index->index_data_size == 0)
-    warn("No entries in index file!");
+    warn("Problem with data file. Is it empty or is another process readning it?");
   if(index->index_data == MAP_FAILED)
     return NULL;
   index->type = SORTED_ARRAY; /* XXX Assume a sorted file for now */
@@ -263,7 +271,10 @@ ffindex_index_t* ffindex_index_parse(FILE *index_file, size_t num_max_entries)
 
 ffindex_entry_t* ffindex_get_entry_by_index(ffindex_index_t *index, size_t entry_index)
 {
-  return &index->entries[entry_index];
+  if(entry_index < index->n_entries)
+    return &index->entries[entry_index];
+  else
+    return NULL;
 }
 
 /* Using a function for this looks like overhead. But a more advanced data format,
